import { Component, ElementRef, ViewChild } from "@angular/core";
import { Router } from "@angular/router";
import { DeviceService } from "../../service/device.service";
import { BuildingService } from "../../service/monitoring-api.service";
import videojs from "video.js";

@Component({
  selector: "app-surveillance",
  templateUrl: "./surveillance.component.html",
  styleUrls: ["./surveillance.component.css"],
})
export class SurveillanceComponent {
  @ViewChild("videoIframe", { static: false }) videoIframe: ElementRef;

  filteredRows: any[];
  searchTerm: string = "";
  buildingSelected: any;
  statusSelected: any;
  categorySelected: any;
  dataMasterCategori: any;
  dataBuildingList: any;
  dataMasterStatus: any;
  storedData: any;
  spinnerFilterActive = false;
  switchState: boolean;
  public breadcrumb: any;
  showIframe = false;
  clicktrue = false;
  cameras = [
    {
      id: 1,
      name: "Pengadilan Agama Padang Cam 1",
      videoUrl:
        "https://pdg2.cctvbadilag.my.id:5443/401900PTAPADANG/play.html?name=034163533934088379392939",
    },
    {
      id: 2,
      name: "Pengadilan Agama Padang Cam 2",
      videoUrl:
        "https://pdg2.cctvbadilag.my.id:5443/401900PTAPADANG/play.html?name=671014455048381705129283",
    },
    {
      id: 3,
      name: "Pengadilan Agama Purwakarta Cam 1",
      videoUrl:
        "https://bdg2.cctvbadilag.my.id:5443/400854PAPURWAKARTA/play.html?name=194533247298993755522217",
    },
    {
      id: 4,
      name: "Pengadilan Agama Purwakarta Cam 2",
      videoUrl:
        "https://bdg2.cctvbadilag.my.id:5443/400854PAPURWAKARTA/play.html?name=113658520181242556385273",
    },
  ];

  constructor(
    private router: Router,
    private deviceService: DeviceService,
    private monitoringApiService: BuildingService
  ) {}

  ngOnInit() {
    this.breadcrumb = {
      mainlabel: "Surveillance",
      links: [
        {
          name: "Home",
          isLink: false,
          link: "",
        },
        {
          name: "Surveillance",
          isLink: false,
        },
      ],
    };
    this.storedData = JSON.parse(localStorage.getItem("currentUser"));
    this.buildingSelected = this.storedData.buildingId;
    this.fetchData(
      this.buildingSelected,
      this.categorySelected,
      this.statusSelected
    );
    this.dataListMaster();
    this.dataListBuilding();
  }

  ngAfterViewInit() {
    //Called after ngAfterContentInit when the component's view has been initialized. Applies to components only.
    //Add 'implements AfterViewInit' to the class.
  }

  fetchData(buildingSelected, categorySelected, statusSelected) {
    this.deviceService
      .getDeviceData(buildingSelected, categorySelected, statusSelected)
      .subscribe((res) => {
        this.filteredRows = res.results.data;
        console.log(this.filteredRows);
      });
  }

  dataListMaster() {
    this.monitoringApiService.getMasterListData().subscribe((data) => {
      const dataCategory = data.data.find(
        (item) => item.name === "master_category"
      ).headerDetailParam;
      const dataStatus = data.data.find(
        (item) => item.name === "master_status"
      ).headerDetailParam;
      this.dataMasterCategori = dataCategory.filter(
        (item) => item.status === "2"
      );
      this.dataMasterStatus = dataStatus.filter((item) => item.status === "2");
    });
  }

  dataListBuilding() {
    this.monitoringApiService.getBuildingList().subscribe((data) => {
      this.dataBuildingList = data.data.filter((item) => item.statusId === 2);
    });
  }

  doFilter() {
    this.spinnerFilterActive = true;
    this.fetchData(
      this.buildingSelected,
      this.categorySelected,
      this.statusSelected
    );
    setTimeout(() => {
      this.spinnerFilterActive = false;
    }, 3000);
  }

  onClick(videoUrl: string) {
    const iframe = this.videoIframe.nativeElement;
    iframe.src = videoUrl;
    this.clicktrue = true;
  }

  onMouseEnter(camera: any) {
    console.log("enter");
    if (this.clicktrue === false) {
      const iframe = this.videoIframe.nativeElement;
      iframe.src = camera.videoUrl;
    }

    this.showIframe = true;
  }

  onMouseLeave() {
    console.log("leave");
    const iframe = this.videoIframe.nativeElement;
    if (this.clicktrue === false) {
      iframe.src = "";
    }
    this.showIframe = false;
  }
}
